#ifndef __LOCAL_PROTO_H__
#define __LOCAL_PROTO_H__

/* support.c */
void write_support(int, char *, double **, double *);

#endif
